@@ -1,12 +1,12 @@
 from bs4 import BeautifulSoup
 
-from kraken_extract_from_html.extractors.extract_feeds import extract_feeds
-from kraken_extract_from_html.extractors.extract_images import extract_images
-from kraken_extract_from_html.extractors.extract_links import extract_links
-from kraken_extract_from_html.extractors.extract_schemas import extract_schemas
-from kraken_extract_from_html.extractors.extract_src import extract_src
-from kraken_extract_from_html.extractors.extract_text import extract_text
-from kraken_extract_from_html.extractors.extract_title import extract_title
+from .extractors.extract_feeds import extract_feeds
+from .extractors.extract_images import extract_images
+from .extractors.extract_links import extract_links
+from .extractors.extract_schemas import extract_schemas
+from .extractors.extract_src import extract_src
+from .extractors.extract_text import extract_text
+from .extractors.extract_title import extract_title
 
 
 
